import request from '@/utils/request'
//获取系统公告列表
export function msgMessageList(params) {
    return request({
        url: '/operate/system/messageList',
        method: 'get',
        params
    })
}
//删除全部已读
export function delIsRead(params) {
    return request({
        url: '/message/delIsRead',
        method: 'get',
        params
    })
}
//全部已读
export function readingNotes(params) {
    return request({
        url: '/message/readingNotes',
        method: 'get',
        params
    })
}
// 查看消息详情
export function GetMessageDetail(params) {
    return request({
      url: '/operate/system/messageDetail',
      method: 'get',
      params
    })
  }
  //是否为paas账号
  export function GetIsPaas(data) {
    return request({
      url: '/operate/system/getIsPaas',
      method: 'post',
      data
    })
  }
  //转发
  export function Forward(data) {
    return request({
      url: '/operate/system/messageFor',
      method: 'post',
      data
    })
  }